@@ -10,22 +10,35 @@ def getOrElse(default, value):
         return default
 
 
-blue = 'blue'
-closed = 'closed'
-create = 'create'
-deleted = 'deleted'
-doing = 'doing'
-green = 'green'
-made = 'made'
-new = 'new'
-new_man = 'new_man'
-red = 'red'
-restarted = 'restarted'
-started = 'started'
-transferred = 'transferred'
-stoped = 'stoped'
-update = 'update'
-value_odd = 'value_odd'
+blue = "blue"
+closed = "closed"
+create = "create"
+deleted = "deleted"
+doing = "doing"
+green = "green"
+made = "made"
+new = "new"
+new_man = "new_man"
+red = "red"
+restarted = "restarted"
+started = "started"
+transferred = "transferred"
+stoped = "stoped"
+update = "update"
+value_odd = "value_odd"
+formirovanie="formirovanie"
+
+name_new="Новый"
+name_new_s="Новый (с)"
+name_new_h="Новый (р)"
+name_started="Запущен"
+name_restarted="Запущен (повторно)"
+name_transferred="Назначенный"
+name_stoped="Остановлен"
+name_doing="Выполнен"
+name_closed="Закрыт"
+name_formirovanie="Формирование"
+name_handmade="Системный (ручное формирование)"
 
 
 def blinkString(text, blink=True, color="black", bold=False) -> Text:
