@@ -1,7 +1,9 @@
+import logging
 import re
 
 from django.db import connection
 
+logger = logging.getLogger(__name__)
 
 def uncapitalize(str):
     return str[0:1].lower() + str[1:]
@@ -33,6 +35,9 @@ def ExecuteStoredProc(storedProcName, parametrs):
         results, = c.fetchone()
         # c.execute("COMMIT")
         return results
+    except Exception as ex:
+        logger.error(ex)
+        raise ex
     finally:
         c.close()
 
