@@ -20,7 +20,7 @@ def exists_base_object(table_name, schem_aname='public'):
     with connection.cursor() as cursor:
         cursor.execute(sql_text, [table_name, schem_aname])
         rows = cursor.fetchone()
-        if rows is None:
+        if rows == None:
             return False
         else:
             return len(rows) > 0
@@ -31,7 +31,7 @@ def create_tmp_mat_view(sql_str, params=[], indexes=[], mat_view_name=None) -> T
         return mat_view_name
 
     key = f'create_tmp_mat_view_{mat_view_name}'
-    if mat_view_name is not None:
+    if mat_view_name != None:
         settings.LOCKS.acquire(key)
     else:
         mat_view_name = f'tmp_{uuid4()}'
@@ -45,19 +45,19 @@ def create_tmp_mat_view(sql_str, params=[], indexes=[], mat_view_name=None) -> T
             logger.debug(f'Creating: {mat_view_name}')
             cursor.execute(sql_txt, params)
             logger.debug(f'Created: {mat_view_name}')
-        if mat_view_name is not None:
+        if mat_view_name != None:
             settings.LOCKS.release(key)
         return mat_view_name
     except Exception as ex:
         exc_info = sys.exc_info()
         logger.error(msg=ex, exc_info=exc_info)
-        if mat_view_name is not None:
+        if mat_view_name != None:
             settings.LOCKS.release(key)
         return None
 
 
 def create_view(sql_str, params=[], view_name=None) -> None:
-    if view_name is None:
+    if view_name == None:
         raise Exception(f'View must have name')
 
     if exists_base_object(view_name):
@@ -110,7 +110,7 @@ def create_insert_update_delete_function_of_table(
                 return f'''{f'{prefix}.' if prefix else ''}"{param_item[0]}"=f{param_item[0]}'''
 
             def func_where_clause_str1(param_item, prefix1=None, prefix2=None):
-                prefix2 = '' if prefix2 is None else f'{prefix2}.'
+                prefix2 = '' if prefix2 == None else f'{prefix2}.'
                 return f'''{f'{prefix1}.' if prefix1 else ''}"{param_item[0]}"={prefix2}"{param_item[0]}"'''
 
             func_params1 = ','.join(f'f{func_param_str(a)}' for a in func_params)
@@ -191,14 +191,14 @@ def create_insert_update_delete_function_of_table(
 
 
 def create_table(fields_str=None, sql_str=None, temporary='', on_commit=None, params=[], indexes=[], unique_indexes=[], primary_key=None, table_name=None, drop=True) -> None:
-    if table_name is None:
+    if table_name == None:
         raise Exception(f'Table must have name')
 
     key = f'create_tmp_table{table_name}'
     settings.LOCKS.acquire(key)
 
     pk_str = ''
-    if primary_key is not None:
+    if primary_key != None:
         if not isinstance(primary_key, list):
             primary_key = [primary_key]
 
@@ -221,10 +221,10 @@ def create_table(fields_str=None, sql_str=None, temporary='', on_commit=None, pa
         sql_txt = f'''DROP TABLE IF EXISTS {table_name} CASCADE;'''
 
     on_commit_str = f'ON COMMIT {on_commit}'
-    if on_commit is None:
+    if on_commit == None:
         on_commit_str = ''
 
-    if sql_str is None:
+    if sql_str == None:
         sql_txt += f'''CREATE {temporary} TABLE {table_name} ({fields_str}) {on_commit_str};'''
     else:
         sql_txt += f'''CREATE {temporary} TABLE {table_name} as ({sql_str}); {on_commit_str};'''
@@ -265,7 +265,7 @@ def drop_mat_view(mat_view_name) -> bool:
 
     sql_txt = f'DROP MATERIALIZED VIEW IF EXISTS {mat_view_name} CASCADE;'
     try:
-        if exists_base_object(mat_view_name) is False:
+        if exists_base_object(mat_view_name) == False:
             return False
 
         key = f'drop_mat_view_{mat_view_name}'
@@ -292,11 +292,11 @@ def refresh_mat_view(mat_view_name, progressStack=None):
     settings.LOCKS.acquire(key)
     try:
         with connection.cursor() as cursor:
-            if progressStack is not None:
+            if progressStack != None:
                 progressStack.setContentsLabel(blinkString(f'Обновление материализованного преставления {mat_view_name}', bold=True))
             cursor.execute(sql_txt)
         settings.LOCKS.release(key)
-        if progressStack is not None:
+        if progressStack != None:
             progressStack.close()
         return True
 
@@ -306,11 +306,11 @@ def refresh_mat_view(mat_view_name, progressStack=None):
         settings.LOCKS.acquire(key)
         try:
             with connection.cursor() as cursor:
-                if progressStack is not None:
+                if progressStack != None:
                     progressStack.setContentsLabel(blinkString(f'Обновление материализованного преставления {mat_view_name}', bold=True))
                 cursor.execute(sql_txt)
             settings.LOCKS.release(key)
-            if progressStack is not None:
+            if progressStack != None:
                 progressStack.close()
             return True
 
@@ -318,7 +318,7 @@ def refresh_mat_view(mat_view_name, progressStack=None):
             exc_info = sys.exc_info()
             logger.error(msg=ex, exc_info=exc_info)
             settings.LOCKS.release(key)
-            if progressStack is not None:
+            if progressStack != None:
                 progressStack.close()
             return False
 
@@ -326,6 +326,6 @@ def refresh_mat_view(mat_view_name, progressStack=None):
         exc_info = sys.exc_info()
         logger.error(msg=ex, exc_info=exc_info)
         settings.LOCKS.release(key)
-        if progressStack is not None:
+        if progressStack != None:
             progressStack.close()
         return False
