@@ -59,17 +59,17 @@ class DSRequest(RPCRequest):
     @property
     def user(self):
         from isc_common.auth.models.user import User
-        if self._user is None:
-            if self.httpHeaders is not None and self.httpHeaders.USER_ID:
+        if self._user == None:
+            if self.httpHeaders != None and self.httpHeaders.USER_ID:
                 self._user = User.objects.get(id=self.httpHeaders.USER_ID)
                 return self._user
             else:
-                if self.transaction is not None:
+                if self.transaction != None:
                     operations = self.transaction.operations
                     if isinstance(operations, list):
                         for operation in operations:
                             data = operation.data
-                            if data.httpHeaders is not None and data.httpHeaders.USER_ID is not None:
+                            if data.httpHeaders != None and data.httpHeaders.USER_ID != None:
                                 self._user = User.objects.get(id=data.httpHeaders.USER_ID)
                                 return self._user
 
@@ -107,7 +107,7 @@ class DSRequest(RPCRequest):
 
     def __init__(self, request):
 
-        if request is not None and request.body != b'':
+        if request != None and request.body != b'':
             self.json = BytesToJson(request.body)
             if isinstance(self.json, dict) and len(self.json) > 0:
                 data = self.json.get('data')
@@ -115,32 +115,32 @@ class DSRequest(RPCRequest):
                     httpHeaders = data.get('httpHeaders')
                     if isinstance(httpHeaders, dict):
 
-                        if httpHeaders.get('WS_CHANNEL') is not None:
+                        if httpHeaders.get('WS_CHANNEL') != None:
                             self.ws_channel = httpHeaders.get('WS_CHANNEL')
 
-                        if httpHeaders.get('WS_PORT') is not None:
+                        if httpHeaders.get('WS_PORT') != None:
                             self.ws_port = httpHeaders.get('WS_PORT')
 
-                        if httpHeaders.get('HOST') is not None:
+                        if httpHeaders.get('HOST') != None:
                             self.host = httpHeaders.get('HOST')
 
-                        if httpHeaders.get('USERNAME') is not None:
+                        if httpHeaders.get('USERNAME') != None:
                             self.set_user_data(user=httpHeaders.get('USERNAME'))
 
-                        if httpHeaders.get('USER_ID') is not None:
+                        if httpHeaders.get('USER_ID') != None:
                             self.set_user_data(user=httpHeaders.get('USER_ID'))
 
                         delAttr(self.json.get('data'), 'httpHeaders')
                     else:
-                        if data.get('user_id') is not None:
+                        if data.get('user_id') != None:
                             self.set_user_data(user=data.get('user_id'))
                 else:
                     login = self.json.get('login')
-                    if login is not None:
+                    if login != None:
                         self.set_user_data(user=login)
                     else:
                         httpHeaders = self.json.get('httpHeaders')
-                        if httpHeaders is not None:
+                        if httpHeaders != None:
                             self.set_user_data(user=httpHeaders.get('USER_ID'))
 
         RPCRequest.__init__(self, self.json)
@@ -203,7 +203,7 @@ class DSRequest(RPCRequest):
                 return (False, [self.get_data()])
 
             res = (True, [dict((key, value) for (key, value) in operation.items() if not str(key).startswith('_') and key not in excluded_keys) for operation in operations])
-            # res = (True, [dict((key, value) for (key, value) in operation.items() if value is not None and not str(key).startswith('_') and key not in excluded_keys) for operation in operations])
+            # res = (True, [dict((key, value) for (key, value) in operation.items() if value != None and not str(key).startswith('_') and key not in excluded_keys) for operation in operations])
         return res
 
     def get_oldValues(self, excluded_keys=['grid']):
@@ -215,7 +215,7 @@ class DSRequest(RPCRequest):
                 res = self.json
 
             res = dict((key, value) for (key, value) in res.items() if not str(key).startswith('_') and key not in excluded_keys)
-            # res = dict((key, value) for (key, value) in res.items() if value is not None and not str(key).startswith('_') and key not in excluded_keys)
+            # res = dict((key, value) for (key, value) in res.items() if value != None and not str(key).startswith('_') and key not in excluded_keys)
         return res
 
     def get_id(self):
@@ -236,7 +236,7 @@ class DSRequest(RPCRequest):
                 ids = [record.get('data').get('id') if record.get('data') else record.get('id') for record in data_array]
         else:
             ids = [0]
-        return [id for id in ids if id is not None]
+        return [id for id in ids if id != None]
 
     def get_tuple_ids(self):
         multi, data_array = self.get_data_array()
@@ -258,7 +258,7 @@ class DSRequest(RPCRequest):
                 ids = [record.get('oldValues').get('id') if record.get('oldValues') else record.get('id') for record in data_array]
         else:
             ids = [0]
-        return [id for id in ids if id is not None]
+        return [id for id in ids if id != None]
 
     def __str__(self):
         return str(self.__dict__)
