@@ -807,13 +807,17 @@ class CommonManager(Manager):
                 res = _data
             else:
                 _data = {k: v for k, v in _data.items() if v != None}
-                res = field.related_model.objects.filter(**_data)
-                if len(res) >= 1:
-                    res = res[0]
-                    res = model_to_dict(res)
-                    for key, value in data.items():
-                        if str(key).find('full_name') != -1:
-                            setAttr(res, 'full_name', value)
+                if isinstance(_data, dict) and len(_data) > 0:
+                    try:
+                        res = field.related_model.objects.filter(**_data)
+                        if len(res) >= 1:
+                            res = res[0]
+                            res = model_to_dict(res)
+                            for key, value in data.items():
+                                if str(key).find('full_name') != -1:
+                                    setAttr(res, 'full_name', value)
+                    except Exception as ex:
+                        logger.error(ex)
                 else:
                     logger.warning(f'Element {_data} not found')
 
