@@ -237,7 +237,7 @@ def handle_com_error(err=None):
 
     :param err: The structure attached to a `pywintypes.com_error`
     """
-    if err is None:
+    if err == None:
         _, err, _ = sys.exc_info()
     hresult_code, hresult_name, additional_info, parameter_in_error = err.args
     hresult_code = signed_to_unsigned(hresult_code)
@@ -283,7 +283,7 @@ def from_time(year=None, month=None, day=None, hours=None, minutes=None, seconds
     """
 
     def str_or_stars(i, length):
-        if i is None:
+        if i == None:
             return "*" * length
         else:
             return str(i).rjust(length, "0")
@@ -376,11 +376,11 @@ class _wmi_method:
 
             self.in_parameters = self.method.InParameters
             self.out_parameters = self.method.OutParameters
-            if self.in_parameters is None:
+            if self.in_parameters == None:
                 self.in_parameter_names = []
             else:
                 self.in_parameter_names = [(i.Name, i.IsArray) for i in self.in_parameters.Properties_]
-            if self.out_parameters is None:
+            if self.out_parameters == None:
                 self.out_parameter_names = []
             else:
                 self.out_parameter_names = [(i.Name, i.IsArray) for i in self.out_parameters.Properties_]
@@ -429,7 +429,7 @@ class _wmi_method:
                 #
                 for k, v in kwargs.items():
                     is_array = parameter_names.get(k)
-                    if is_array is None:
+                    if is_array == None:
                         raise AttributeError("%s is not a valid parameter for %s" % (k, self.__doc__))
                     else:
                         if is_array:
@@ -554,12 +554,12 @@ class _wmi_object:
             handle_com_error()
 
     def _cached_properties(self, attribute):
-        if self.properties[attribute] is None:
+        if self.properties[attribute] == None:
             self.properties[attribute] = _wmi_property(self.ole_object.Properties_(attribute))
         return self.properties[attribute]
 
     def _cached_methods(self, attribute):
-        if self.methods[attribute] is None:
+        if self.methods[attribute] == None:
             self.methods[attribute] = _wmi_method(self.ole_object, attribute)
         return self.methods[attribute]
 
@@ -629,7 +629,7 @@ class _wmi_object:
         # NB You can get the keys of an instance more directly, via
         # Path\_.Keys but this doesn't apply to classes. The technique
         # here appears to work for both.
-        if self._keys is None:
+        if self._keys == None:
             _set(self, "_keys", [])
             for property in self.ole_object.Properties_:
                 for qualifier in property.Qualifiers_:
@@ -702,7 +702,7 @@ class _wmi_object:
             handle_com_error()
 
     def _cached_associated_classes(self):
-        if self._associated_classes is None:
+        if self._associated_classes == None:
             if isinstance(self, _wmi_class):
                 params = {'bSchemaOnly': True}
             else:
@@ -839,7 +839,7 @@ class _wmi_class(_wmi_object):
         """
         #
         #
-        if self._namespace is None:
+        if self._namespace == None:
             raise x_wmi_no_namespace("You cannot query directly from a WMI class")
 
         try:
@@ -860,7 +860,7 @@ class _wmi_class(_wmi_object):
             fields=[],
             **where_clause
     ):
-        if self._namespace is None:
+        if self._namespace == None:
             raise x_wmi_no_namespace("You cannot watch directly from a WMI class")
 
         valid_notification_types = ("operation", "creation", "deletion", "modification")
@@ -980,7 +980,7 @@ class _wmi_namespace:
         return repr(self)
 
     def _get_classes(self):
-        if self._classes is None:
+        if self._classes == None:
             self._classes = self.subclasses_of()
         return SelfDeprecatingDict(dict.fromkeys(self._classes))
 
